@@ -1,10 +1,7 @@
 #' Import data to `EViews` workfile
 #'
-#' Use this function to import data to `EViews` workfile from R
+#' Use this function  in R, R Markdown and Quarto to import data to `EViews` workfile.
 #'
-#' @usage eviews_import(source_description="",wf="",type="",options="",smpl_string="",
-#' genr_string="",rename_string="",frequency="",start_date="",id="",destid="",
-#' append=FALSE,save_path="")
 #' @inheritParams eviews_graph
 #' @inheritParams eviews_wfcreate
 #' @param type Optional. Specify the file type, it can values allowed by `EViews` \code{import} commands like \code{access}, \code{text}. For the most part, you should not need to specify a “type=” option as EViews will automatically determine the type from the filename.
@@ -21,24 +18,29 @@
 #'
 #' @examples library(EviewsR)
 #' \dontrun{
-#' x=runif(100); y=runif(100); data=data.frame(x,y)
-#' write.csv(data,"EviewsR_eviews_import.csv",row.names = FALSE)
+#' Data=data.frame(x=cumsum(rnorm(100)),y=cumsum(rnorm(100)))
+#' write.csv(Data,"eviews_import.csv",row.names = FALSE)
 #'
-#' eviews_import(source_description = "EviewsR_eviews_import.csv",start_date = "1990",frequency = "m",
+#' eviews_import(source_description = "eviews_import.csv",start_date = "1990",frequency = "m",
 #' rename_string = "x ab",smpl_string = "1990m10 1992m10")
 #'
-#' Alternatively, use the dataframe as the source_description
+#' # Alternatively, use the dataframe as the source_description
 #'
-#' eviews_import(source_description = data,wf="EviewsR_eviews_import1",start_date = "1990",
+#' eviews_import(source_description = Data,wf="eviews_import1",start_date = "1990",
 #' frequency = "m",rename_string = "x ab",smpl_string = "1990m10 1992m10")
 #'}
 #' @family important functions
 #' @keywords documentation
 #' @export
-eviews_import=function(source_description="",wf="",type="",options="",smpl_string="",genr_string="",rename_string="",frequency="",start_date="",id="",destid="",append=FALSE,save_path=""){
+eviews_import=function(source_description="",wf="",type="",options="",smpl_string="",genr_string="",rename_string="",frequency="",start_date="",id="",destid="",append=FALSE,save_path=dirname(wf)){
+
+  if(is.xts(source_description)) source_description=data.frame(date=index(source_description),coredata(source_description))
+
+   wf1= wf %>% shQuote_cmd %>% paste0('%wf1=',.)
 
   if(is.data.frame(source_description)){
-    if(wf=="") wf=paste0(paste0(names(source_description),collapse = ""),"_EviewsR")
+
+   if(wf=="") wf=paste0(paste0(names(source_description),collapse = ""),"_",tempfile("") %>% basename)
     csvFile=paste0(wf,".csv")
     write.csv(source_description,csvFile,row.names = FALSE)
 
@@ -49,22 +51,28 @@ eviews_import=function(source_description="",wf="",type="",options="",smpl_strin
 
 
     fileName=tempfile("EVIEWS", ".", ".prg")
-  options=paste0('%options=',shQuote(options))
-  # source_description=gsub("/","\\\\",source_description)
-  source_description=paste0("%source_description=",shQuote(source_description))
-  smpl_string=paste0("%smpl_string=",shQuote(smpl_string))
-  genr_string=paste0("%genr_string=",shQuote(genr_string))
-  rename_string=paste0("%rename_string=",shQuote(rename_string))
-  frequency=paste0("%frequency=",shQuote(frequency))
-  start_date=paste0("%start_date=",shQuote(start_date))
-  id=paste0("%id=",shQuote(id))
-  destid=paste0("%destid=",shQuote(destid))
-  append=paste0("%append=",shQuote(append))
-  wf=paste0("%wf=",shQuote(wf))
+  options=paste0('%options=',shQuote_cmd(options))
+  source_description=paste0("%source_description=",shQuote_cmd(source_description))
+  smpl_string=paste0("%smpl_string=",shQuote_cmd(smpl_string))
+  genr_string=paste0("%genr_string=",shQuote_cmd(genr_string))
+  rename_string=paste0("%rename_string=",shQuote_cmd(rename_string))
+  frequency=paste0("%frequency=",shQuote_cmd(frequency))
+  start_date=paste0("%start_date=",shQuote_cmd(start_date))
+  id=paste0("%id=",shQuote_cmd(id))
+  destid=paste0("%destid=",shQuote_cmd(destid))
+  append=paste0("%append=",shQuote_cmd(append))
   save_path1=save_path
-  save_path=paste0("%save_path=",shQuote(save_path))
+  if(save_path1=="") save_path1="."
+  if(!dir.exists(save_path1)) dir.create(save_path1,recursive = T)
+  save_path=paste0("%save_path=",shQuote_cmd(save_path))
+  wf=paste0("%wf=",shQuote_cmd(wf))
+
+  eviewsCode=r'(
+  %wf2=%wf+".wf1"
+ if %wf1<>"" and @fileexist(%wf2) and %start_date="" then
+open {%wf1}
+  endif
 
-  eviews_code=r'(
   if %type<>"" then
   %type="type="+%type+","   'to avoid error if %TYPE=""
   endif
@@ -88,12 +96,12 @@ eviews_import=function(source_description="",wf="",type="",options="",smpl_strin
 
   'Determine the IMPORT_SPECIFICATION for DATED
 
-  if %frequency<>"" or %start_date<>"" then
+  if %frequency<>"" and %start_date<>"" then
   %import_type="dated"
   %import_specification="@freq "+%frequency+" "+%start_date
   endif
 
-  if %id<>"" or %destid<>"" then
+  if %id<>"" and %destid<>"" then
   %import_type="match-merged"
   'open {%wf}
   %import_specification="@id "+%id+" @destid"+" "+%destid
@@ -101,7 +109,7 @@ eviews_import=function(source_description="",wf="",type="",options="",smpl_strin
 
   if (%append="T" or %append="TRUE") and %id="" and %destid="" and %frequency="" and %start_date="" then
   %import_type="appended"
-  open {%wf}
+  'open {%wf}
     %import_specification="@append"
   endif
 
@@ -118,11 +126,11 @@ eviews_import=function(source_description="",wf="",type="",options="",smpl_strin
 
   %optional_arguments=%smpl_string+" "+%genr_string+" "+%rename_string
   if %import_type="appended" then
-  'open {%wf}
+ 'open {%wf}
   %optional_arguments=%genr_string+" "+%rename_string 'APPENDED syntax does not contain @SMPL_STRING
   endif
   'GENERAL
-  import({%type}{%options}) {%source_description} colhead=1  {%import_specification} {%optional_arguments}
+  import({%type}{%options}) {%source_description} {%import_specification} {%optional_arguments}
 
   %wf=@wfname
 
@@ -135,16 +143,9 @@ eviews_import=function(source_description="",wf="",type="",options="",smpl_strin
 exit
   )'
 
-writeLines(c(eviews_path(),wf,save_path,type,options,source_description,smpl_string,genr_string,rename_string,frequency,start_date,id,destid,append,eviews_code),fileName)
+writeLines(c(eviews_path(),wf,wf1,save_path,type,options,source_description,smpl_string,genr_string,rename_string,frequency,start_date,id,destid,append,eviewsCode),fileName)
 
 
-  if(save_path1!=""){
-    if(!dir.exists(save_path1)) dir.create(save_path1,recursive = T)
-  }
-
   system_exec()
   on.exit(unlink_eviews(),add = TRUE)
 }
-
-
-# eviews_import(source_description = "eviews/somefilename.csv",start_date = "1990",frequency = " m",rename_string = " series01 ab",smpl_string = "1990m10 1992m10")
