@@ -1,10 +1,7 @@
-#' Save an `EViews` workfile page from R
+#' Save an `EViews` workfile page.
 #'
-#' Use this function to save an `EViews` workfile page from R
+#' Use this function in  R, R Markdown and Quarto to save an `EViews` workfile page.
 #'
-#' @usage eviews_pagesave(wf="",page="",options="",source_description="",
-#' table_description="",keep_list="",drop_list="",keepmap_list="",dropmap_list="",
-#' smpl_spec="")
 #' @inheritParams eviews_graph
 #' @param options Object or a character string of any of the acceptable `EViews` \code{pagesave} options, such as \code{noid}, \code{nomapval}, \code{nonames}.
 #' @param source_description The path and name of the file to be saved.
@@ -20,38 +17,40 @@
 #' \dontrun{
 #' demo(exec_commands)
 #'
-#' eviews_pagesave(wf="EviewsR_exec_commands",source_description = "EviewsR_eviews_pagesave.csv",
+#' eviews_pagesave(wf="exec_commands",source_description = "eviews_pagesave.csv",
 #' drop_list = "y")
 #'}
 #' @family important functions
 #' @keywords documentation
 #' @export
-eviews_pagesave=function(wf="",page="",options="",source_description="",table_description="",keep_list="",drop_list="",keepmap_list="",dropmap_list="",smpl_spec=""){
+eviews_pagesave=function(wf="",page="",options="",source_description="",table_description="",keep_list="",drop_list="",keepmap_list="",dropmap_list="",smpl_spec="",save_path=dirname(source_description)){
+
+  if(!dir.exists(save_path)) dir.create(save_path,recursive = T)
 
   fileName=tempfile("EVIEWS", ".", ".prg")
-  wf=paste0('%wf=',shQuote(wf))
-  page=paste0('%page=',shQuote(page))
+  wf=paste0('%wf=',shQuote_cmd(wf))
+  page=paste0('%page=',shQuote_cmd(page))
 
   options=paste(options,collapse = ",")
-  options=paste0('%options=',shQuote(options))
-  source_description=paste0('%source_description=',shQuote(source_description))
-  table_description=paste0('%table_description=',shQuote(table_description))
+  options=paste0('%options=',shQuote_cmd(options))
+  source_description=paste0('%source_description=',shQuote_cmd(source_description))
+  table_description=paste0('%table_description=',shQuote_cmd(table_description))
 
   keep_list=paste(keep_list,collapse = " ")
-  keep_list=paste0('%keep_list=',shQuote(keep_list))
+  keep_list=paste0('%keep_list=',shQuote_cmd(keep_list))
 
   drop_list=paste(drop_list,collapse = " ")
-  drop_list=paste0('%drop_list=',shQuote(drop_list))
+  drop_list=paste0('%drop_list=',shQuote_cmd(drop_list))
 
   keepmap_list=paste(keepmap_list,collapse = " ")
-  keepmap_list=paste0('%keepmap_list=',shQuote(keepmap_list))
+  keepmap_list=paste0('%keepmap_list=',shQuote_cmd(keepmap_list))
 
   dropmap_list=paste(dropmap_list,collapse = " ")
-  dropmap_list=paste0('%dropmap_list=',shQuote(dropmap_list))
+  dropmap_list=paste0('%dropmap_list=',shQuote_cmd(dropmap_list))
 
-  smpl_spec=paste0('%smpl_spec=',shQuote(smpl_spec))
+  smpl_spec=paste0('%smpl_spec=',shQuote_cmd(smpl_spec))
 
-  eviews_code=r'(open {%wf}
+  eviewsCode=r'(open {%wf}
 
 if %page<>"" then
 pageselect {%page}
@@ -79,15 +78,12 @@ if %smpl_spec<>"" then
 %smpl_spec="@smpl "+%smpl_spec
 endif
 
-pagesave(%options) {%source_description} {%table_description} {%keep_list} {%drop_list} {%keepmap_list} {%dropmap_list} {%smpl_spec}
+pagesave(%options) %source_description {%table_description} {%keep_list} {%drop_list} {%keepmap_list} {%dropmap_list} {%smpl_spec}
 exit
 )'
 writeLines(c(eviews_path(),wf,page,options,source_description,table_description,keep_list,drop_list,keepmap_list,dropmap_list,smpl_spec
-,eviews_code),fileName)
+,eviewsCode),fileName)
 
   system_exec()
   on.exit(unlink_eviews(),add = TRUE)
 }
-
-
-# eviews_pagesave(wf="eviews/workfile",source_description = "eviews/path/EviewsR.csv",drop_list = "y")
