@@ -1,10 +1,7 @@
-#' Create an `EViews` workfile from R
+#' Create an `EViews` workfile.
 #'
-#' Use this function to create an `EViews` workfile from R
+#' Use this function  in R, R Markdown and Quarto to create an `EViews` workfile.
 #'
-#' @usage eviews_wfcreate(source_description="",wf="",page="",prompt=F,frequency="",
-#' subperiod_opts="",start_date="",end_date="",num_cross_sections=NA,num_observations=NA,
-#' save_path="")
 #' @param wf Object or a character string representing the name of a workfile to be created
 #' @param page Object or a character string representing the name of a workfile page to be created
 #'
@@ -24,31 +21,37 @@
 #'
 #' @examples library(EviewsR)
 #' \dontrun{
-#' eviews_wfcreate(wf="EviewsR_eviews_wfcreate",page="EviewsR_page",frequency = "m",
+#' eviews_wfcreate(wf="eviews_wfcreate",page="EviewsR_page",frequency = "m",
 #' start_date = "1990",end_date = "2022")
+#'
+#' # Create a workfile from a dataframe
+#'
+#' Data=data.frame(x=cumsum(rnorm(100)),y=cumsum(rnorm(100)))
+#'
+#' eviews_wfcreate(source_description=Data,wf="eviews_wfcreate1",page="EviewsR_page",frequency="m",
+#' start_date="1990")
 #'}
 #' @family important functions
 #' @keywords documentation
 #' @export
-eviews_wfcreate=function(source_description="",wf="",page="",prompt=F,frequency="",subperiod_opts="",start_date="",end_date="",num_cross_sections=NA,num_observations=NA,save_path=""){
+eviews_wfcreate=function(source_description="",wf="",page="",prompt=FALSE,frequency="",subperiod_opts="",start_date="",end_date="",num_cross_sections=NA,num_observations=NA,save_path=dirname(wf)){
+
+  if(is.xts(source_description)) source_description=data.frame(date=index(source_description),coredata(source_description))
+
+if (wf!='') wf=basename(wf)
 
-  if(toupper(frequency)=="U" & is.na(num_observations)) stop("If 'frequency=\"u\"' (undated workfile),'num_observations' cannot be NA or blank")
-  if(toupper(frequency)!="U" & (start_date=="" & is.na(num_observations))) stop("If 'frequency' is not equal to \"u\" (dated workfile),'start_date' and 'num_observations' cannot be blank or NA")
-  if(toupper(frequency)!="U" & (start_date!="" & end_date=="" & is.na(num_observations))) stop("If 'frequency' is not equal to \"u\" (dated workfile) and 'start_date' is not blank, then 'end_date' or 'num_observations' cannot be blank or NA")
 
-  if(start_date!="" && !is.na(num_observations) && end_date=="") end_date=paste0('+',num_observations)
 
   save_path=gsub("/","\\\\",save_path)
   save_path1=save_path
-  save_path=paste0("%save_path=",shQuote(save_path))
+  if(save_path1=="") save_path1="."
+  if(!dir.exists(save_path1)) dir.create(save_path1,recursive = T)
 
-   if(save_path1!=""){
-     if(!dir.exists(save_path1)) dir.create(save_path1,recursive = T)
-  }
+  save_path=paste0("%save_path=",shQuote_cmd(save_path))
 
 if(is.data.frame(source_description)){
 
-    if(wf=="") wf=paste0(paste0(names(source_description),collapse = ""),"_Workfile")
+    if(wf=="") wf=paste0(paste0(names(source_description),collapse = ""),"_",tempfile("") %>% basename)
 
     csvFile=paste0(wf,".csv")
     write.csv(source_description,csvFile,row.names = FALSE)
@@ -56,31 +59,39 @@ if(is.data.frame(source_description)){
     on.exit(unlink(csvFile),add = T)
   }else{
 
+    if(toupper(frequency)=="U" & is.na(num_observations)) stop("If 'frequency=\"u\"' (undated workfile),'num_observations' cannot be NA or blank")
+    if(toupper(frequency)!="U" & (start_date=="" & is.na(num_observations))) stop("If 'frequency' is not equal to \"u\" (dated workfile),'start_date' and 'num_observations' cannot be blank or NA")
+    if(toupper(frequency)!="U" & (start_date!="" & end_date=="" & is.na(num_observations))) stop("If 'frequency' is not equal to \"u\" (dated workfile) and 'start_date' is not blank, then 'end_date' or 'num_observations' cannot be blank or NA")
+
+    if(end_date!="" & !is.na(num_observations)) stop("Please set the value of either 'end_date=\"\"' or  'num_observations=NA'.")
+
+    if(start_date!="" && !is.na(num_observations) && end_date=="") end_date=paste0('+',num_observations)
+
   fileName=tempfile("EVIEWS", ".", ".prg")
 
 if(wf=="") wf=basename(gsub(".prg","",fileName))
 if(page=="") page=wf
-if(prompt==T) prompt="prompt"
+if(prompt) prompt="prompt" else prompt=""
 
 wf=paste0("wf=",wf)
 page=paste0("page=",page)
 
   options=paste(wf,page,prompt,sep = ",")
-  options=paste0("%options=",shQuote(options))
+  options=paste0("%options=",shQuote_cmd(options))
 
-  frequency=paste0("%frequency=",shQuote(frequency))
-  subperiod_opts=paste0("%subperiod_opts=",shQuote(subperiod_opts))
-  start_date=paste0("%start_date=",shQuote(start_date))
-  end_date=paste0("%end_date=",shQuote(end_date))
+  frequency=paste0("%frequency=",shQuote_cmd(frequency))
+  subperiod_opts=paste0("%subperiod_opts=",shQuote_cmd(subperiod_opts))
+  start_date=paste0("%start_date=",shQuote_cmd(start_date))
+  end_date=paste0("%end_date=",shQuote_cmd(end_date))
   num_cross_sections=paste0("!num_cross_sections=",num_cross_sections)
   num_observations=paste0("!num_observations=",num_observations)
 
 
-  eviews_code=r'('%wf=@wreplace(%wf,"* ","*")
+  eviewsCode=r'(%wf=@wreplace(%wf,"* ","*")
   '%page=@wreplace(%page,"* ","*")
   %subperiod_opts=@wreplace(%subperiod_opts,"* ","*")
 
-  @stripcommas(%options)
+  %options=@stripcommas(%options)
 
   if %subperiod_opts<>"" then
   %subperiod_opts="("+%subperiod_opts+")"
@@ -108,7 +119,7 @@ page=paste0("page=",page)
   exit
   )'
 
-writeLines(c(eviews_path(),options,save_path,frequency,subperiod_opts,start_date,end_date,num_cross_sections,num_observations,save_path,eviews_code),fileName)
+writeLines(c(eviews_path(),options,save_path,frequency,subperiod_opts,start_date,end_date,num_cross_sections,num_observations,save_path,eviewsCode),fileName)
 
 
   system_exec()
@@ -117,7 +128,3 @@ writeLines(c(eviews_path(),options,save_path,frequency,subperiod_opts,start_date
 }
 
 }
-
-
-
-# eviews_wfcreate(wf="smati",page="academy",frequency = "m",start_date = "1990",end_date = "2020",num_observations = 2,save_path = "eviews/path")
